==> zio-aws-ec2_2.13-5.17.194.1-sources.jar: zio/aws/ec2/model/InstanceSpecification.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.InstanceId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class InstanceSpecification(
    instanceId: Optional[InstanceId] = Optional.Absent,
    excludeBootVolume: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.InstanceSpecification = {
    import InstanceSpecification.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.InstanceSpecification
      .builder()
      .optionallyWith(
        instanceId.map(value => InstanceId.unwrap(value): java.lang.String)
      )(_.instanceId)
      .optionallyWith(excludeBootVolume.map(value => value: java.lang.Boolean))(
        _.excludeBootVolume
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.InstanceSpecification.ReadOnly =
    zio.aws.ec2.model.InstanceSpecification.wrap(buildAwsValue())
}
object InstanceSpecification {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.InstanceSpecification
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.InstanceSpecification =
      zio.aws.ec2.model.InstanceSpecification(
        instanceId.map(value => value),
        excludeBootVolume.map(value => value)
      )
    def instanceId: Optional[InstanceId]
    def excludeBootVolume: Optional[Boolean]
    def getInstanceId: ZIO[Any, AwsError, InstanceId] =
      AwsError.unwrapOptionField("instanceId", instanceId)
    def getExcludeBootVolume: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("excludeBootVolume", excludeBootVolume)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.InstanceSpecification
  ) extends zio.aws.ec2.model.InstanceSpecification.ReadOnly {
    override val instanceId: Optional[InstanceId] = zio.aws.core.internal
      .optionalFromNullable(impl.instanceId())
      .map(value => zio.aws.ec2.model.primitives.InstanceId(value))
    override val excludeBootVolume: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.excludeBootVolume())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.InstanceSpecification
  ): zio.aws.ec2.model.InstanceSpecification.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.19.26.1-sources.jar: zio/aws/ec2/model/InstanceSpecification.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{VolumeId, InstanceId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class InstanceSpecification(
    instanceId: Optional[InstanceId] = Optional.Absent,
    excludeBootVolume: Optional[Boolean] = Optional.Absent,
    excludeDataVolumeIds: Optional[Iterable[VolumeId]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.InstanceSpecification = {
    import InstanceSpecification.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.InstanceSpecification
      .builder()
      .optionallyWith(
        instanceId.map(value => InstanceId.unwrap(value): java.lang.String)
      )(_.instanceId)
      .optionallyWith(excludeBootVolume.map(value => value: java.lang.Boolean))(
        _.excludeBootVolume
      )
      .optionallyWith(
        excludeDataVolumeIds.map(value =>
          value.map { item =>
            VolumeId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.excludeDataVolumeIds)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.InstanceSpecification.ReadOnly =
    zio.aws.ec2.model.InstanceSpecification.wrap(buildAwsValue())
}
object InstanceSpecification {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.InstanceSpecification
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.InstanceSpecification =
      zio.aws.ec2.model.InstanceSpecification(
        instanceId.map(value => value),
        excludeBootVolume.map(value => value),
        excludeDataVolumeIds.map(value => value)
      )
    def instanceId: Optional[InstanceId]
    def excludeBootVolume: Optional[Boolean]
    def excludeDataVolumeIds: Optional[List[VolumeId]]
    def getInstanceId: ZIO[Any, AwsError, InstanceId] =
      AwsError.unwrapOptionField("instanceId", instanceId)
    def getExcludeBootVolume: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("excludeBootVolume", excludeBootVolume)
    def getExcludeDataVolumeIds: ZIO[Any, AwsError, List[VolumeId]] =
      AwsError.unwrapOptionField("excludeDataVolumeIds", excludeDataVolumeIds)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.InstanceSpecification
  ) extends zio.aws.ec2.model.InstanceSpecification.ReadOnly {
    override val instanceId: Optional[InstanceId] = zio.aws.core.internal
      .optionalFromNullable(impl.instanceId())
      .map(value => zio.aws.ec2.model.primitives.InstanceId(value))
    override val excludeBootVolume: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.excludeBootVolume())
      .map(value => value: Boolean)
    override val excludeDataVolumeIds: Optional[List[VolumeId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.excludeDataVolumeIds())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.primitives.VolumeId(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.InstanceSpecification
  ): zio.aws.ec2.model.InstanceSpecification.ReadOnly = new Wrapper(impl)
}
